# Copyright (c) 2000-2005, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%define section devel

%define with_aspectj 0

Summary:        AOP for Java
Name:           aspectwerkz
Version:        2.0
Release:        %mkrel 3
Epoch:          0
License:        BSD
URL:            http://aspectwerkz.codehaus.org/
Group:          Development/Java
Source0:        http://dist.codehaus.org/aspectwerkz/distributions/aspectwerkz-2.0.zip
# ok
Source1:        http://repo1.maven.org/maven2/aspectwerkz/aspectwerkz/2.0/aspectwerkz-2.0.pom
# TODO need asm 1.5.4-snapshot
Source2:        http://repo1.maven.org/maven2/aspectwerkz/aspectwerkz-core/2.0/aspectwerkz-core-2.0.pom
# ok
Source3:        http://repo1.maven.org/maven2/aspectwerkz/aspectwerkz-extensions/2.0/aspectwerkz-extensions-2.0.pom
# ok
Source4:        http://repo1.maven.org/maven2/aspectwerkz/aspectwerkz-jdk14/2.0/aspectwerkz-jdk14-2.0.pom
# ok
Source5:        http://repo1.maven.org/maven2/aspectwerkz/aspectwerkz-nodeps-jdk14/2.0/aspectwerkz-nodeps-jdk14-2.0.pom
# ok
Source6:        http://repo1.maven.org/maven2/aspectwerkz/aspectwerkz-nodeps-jdk5/2.0/aspectwerkz-nodeps-jdk5-2.0.pom
Patch0:         aspectwerkz2-build_xml.patch
Patch1:         aspectwerkz2-script.patch
Patch2:         aspectwerkz2-script2.patch
Patch3:         aspectwerkz2-javahome.patch
BuildRequires:  jpackage-utils
BuildRequires:	junit
BuildRequires:  ant
BuildRequires:  java-devel 
BuildRequires:  asm
BuildRequires:  concurrent
BuildRequires:  dom4j
BuildRequires:  geronimo-j2ee-management-1.0-api
BuildRequires:  jarjar
BuildRequires:  javassist
BuildRequires:  jrexx
BuildRequires:  piccolo
#BuildRequires:  qdox16
BuildRequires:  qdox
BuildRequires:  gnu.trove
BuildRequires:  junitperf

# compiler-extensions
BuildRequires:  aopalliance
# TODO
%if %with_aspectj
#BuildRequires:  aspectj
%endif

BuildRequires:  cglib
BuildRequires:  asm2

Requires:       concurrent
Requires:       dom4j
Requires:       javassist
Requires:       jrexx
Requires:       piccolo
Requires:       qdox
#Requires:       qdox16
Requires:       gnu.trove
BuildArch:      noarch

%description
AspectWerkz is a dynamic, lightweight and 
high-performant AOP/AOSD framework for Java. 
AspectWerkz utilizes runtime bytecode modification 
to weave your classes at runtime. It hooks in and 
weaves classes loaded by any class loader except 
the bootstrap class loader. It has a rich join 
point model. Aspects, advices and introductions 
are written in plain Java and your target classes 
can be regular POJOs. You have the possibility to 
add, remove and re-structure advices as well as 
swapping the implementation of your introductions at 
runtime. Your aspects can be defined using either an 
XML definition file or using Runtime Attributes. 


%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Java

%description javadoc
%{summary}.

%package manual
Summary:        Documents for %{name}
Group:          Development/Java

%description manual
%{summary}.

%package demo
Summary:        Samples for %{name}
Group:          Development/Java

%description demo
%{summary}.

%prep
%setup -q -n %{name}-%{version}

for j in $(find . -name "*.jar"); do
  mv $j $j.no
done

chmod +x bin/aspectwerkz

%patch0 -b .sav
%patch1 -b .sav
%patch2
#sed -i "s|qdox|qdox16|" bin/aspectwerkz
%patch3
sed -i "s|@@JAVA_HOME@@|%{_jvmdir}/java|" bin/aspectwerkz

# FIXME Remove the BEA JRockit specific code or it will only build on BEA JDK
# org/codehaus/aspectwerkz/extension/jrockit/JRockitPreProcessor.class
rm -fr src/extensions/org/codehaus/aspectwerkz/extension/jrockit

%build
export ASPECTWERKZ_HOME=$RPM_BUILD_DIR/%{name}-%{version}
ln -sf $(build-classpath geronimo-j2ee-management-1.0-api) lib/j2ee-management.jar
#ln -sf $(build-classpath qdox16) lib/qdox.jar
pushd src/compiler-extensions/aop-alliance/lib
  ln -sf $(build-classpath aopalliance) aopalliance-1.0.jar
popd

# TODO
pushd src/compiler-extensions/spring/lib
# http://www.springsource.org/
  ln -sf $(build-classpath aopalliance) aopalliance-1.0.jar
# circular dependency
# mv spring-aop-1.1.1.jar.no spring-aop-1.1.1.jar 
# mv aw-ext-aopalliance-0.1.jar.no aw-ext-aopalliance-0.1.jar
popd
pushd src/compiler-extensions/aspectj/lib
%if %with_aspectj
  ln -sf $(build-classpath aspectjtools) aspectjtools.jar
  ln -sf $(build-classpath aspectjrt) aspectjrt.jar
%else
  mv aspectjtools.jar.no aspectjtools.jar
  mv aspectjrt.jar.no aspectjrt.jar
%endif
popd
pushd src/cglib-ext/lib
  ln -sf $(build-classpath asm2/asm2) asm.jar
  ln -sf $(build-classpath asm2/asm2-attrs-2.2.3) asm-attrs.jar
  ln -sf $(build-classpath asm2/asm2-util) asm-util.jar
  ln -sf $(build-classpath cglib) cglib-2.0.2.jar
popd

build-jar-repository -s -p lib \
jarjar \
asm/asm \
asm/asm-attrs \
asm/asm-util \
dom4j \
gnu.trove \
concurrent \
junit \
jrexx \
javassist \
piccolo \
qdox \
junitperf \

export JAVA_HOME=%{_jvmdir}/java
ant -Djdk15=%{_jvmdir}/java-gcj test cleandist samples

%install
rm -rf $RPM_BUILD_ROOT

# jars
mkdir -p $RPM_BUILD_ROOT%{_javadir}
cp -p target/%{name}-%{version}.jar \
  $RPM_BUILD_ROOT%{_javadir}/%{name}-%{version}.jar
cp -p target/%{name}-core-%{version}.jar \
  $RPM_BUILD_ROOT%{_javadir}/%{name}-core-%{version}.jar
cp -p target/%{name}-extensions-%{version}.jar \
  $RPM_BUILD_ROOT%{_javadir}/%{name}-extensions-%{version}.jar
cp -p target/%{name}-jdk14-%{version}.jar \
  $RPM_BUILD_ROOT%{_javadir}/%{name}-jdk14-%{version}.jar
cp -p target/%{name}-nodeps-%{version}.jar \
  $RPM_BUILD_ROOT%{_javadir}/%{name}-nodeps-%{version}.jar
cp -p target/%{name}-nodeps-jdk14-%{version}.jar \
  $RPM_BUILD_ROOT%{_javadir}/%{name}-nodeps-jdk14-%{version}.jar
(cd $RPM_BUILD_ROOT%{_javadir} && for jar in *-%{version}.jar; do ln -sf ${jar} `echo $jar| sed "s|-%{version}||g"`; done)
mkdir -p $RPM_BUILD_ROOT%{_bindir}
cp -p bin/aspectwerkz $RPM_BUILD_ROOT%{_bindir}

# javadoc
mkdir -p $RPM_BUILD_ROOT%{_javadocdir}/%{name}
cp -pr docs/apidocs/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}
rm -rf docs/apidocs

# demo
mkdir -p $RPM_BUILD_ROOT%{_datadir}/%{name}-%{version}/src
mkdir -p $RPM_BUILD_ROOT%{_datadir}/%{name}-%{version}/classes
mkdir -p $RPM_BUILD_ROOT%{_datadir}/%{name}-%{version}/bin
cp -pr target/samples-classes/* $RPM_BUILD_ROOT%{_datadir}/%{name}-%{version}/classes
cp -pr src/samples/* $RPM_BUILD_ROOT%{_datadir}/%{name}-%{version}/src

# manual
mkdir -p $RPM_BUILD_ROOT%{_docdir}/%{name}
cp -pr docs/* $RPM_BUILD_ROOT%{_docdir}/%{name}
cp -p LICENSE.txt $RPM_BUILD_ROOT%{_docdir}/%{name}

%clean
rm -rf $RPM_BUILD_ROOT

%files
%doc %{_docdir}/%{name}/LICENSE.txt
%{_javadir}/aspectwerkz-%{version}.jar
%{_javadir}/aspectwerkz.jar
%{_javadir}/aspectwerkz-core-%{version}.jar
%{_javadir}/aspectwerkz-core.jar
%{_javadir}/aspectwerkz-extensions-%{version}.jar
%{_javadir}/aspectwerkz-extensions.jar
%{_javadir}/aspectwerkz-nodeps-%{version}.jar
%{_javadir}/aspectwerkz-nodeps.jar
%{_javadir}/aspectwerkz-jdk14-%{version}.jar
%{_javadir}/aspectwerkz-jdk14.jar
%{_javadir}/aspectwerkz-nodeps-jdk14-%{version}.jar
%{_javadir}/aspectwerkz-nodeps-jdk14.jar
%attr(755, root, root) %{_bindir}/aspectwerkz
%dir %{_datadir}/aspectwerkz-%{version}

%files javadoc
%{_javadocdir}/%{name}

%files manual
%doc %{_docdir}/%{name}

%files demo
%{_datadir}/%{name}-%{version}


%changelog

* Wed Oct 19 2011 dmorgan <dmorgan> 0:2.0-3.mga2
+ Revision: 156594
- imported package aspectwerkz

  + gil <gil>
    - edit spec file


* Sun Dec 16 2007 Alexander Kurtakov <akurtakov@mandriva.org> 2.0-2.0.1mdv2008.1
+ Revision: 120741
- remove vendor, distribution tags
- import aspectwerkz


